# Generated by Django 2.1.4 on 2018-12-13 19:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0008_auto_20181206_1640'),
    ]

    operations = [
        migrations.CreateModel(
            name='Endpoint',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.SlugField(help_text='The name of your endpoint.', max_length=100, unique=True)),
                ('url', models.URLField(blank=True, help_text='A URL to hit with the processed and validated form data.')),
                ('token', models.SlugField(editable=False, max_length=30, unique=True)),
            ],
        ),
        migrations.RemoveField(
            model_name='form',
            name='webhook',
        ),
        migrations.AddField(
            model_name='form',
            name='endpoint',
            field=models.ForeignKey(help_text='A URL to hit with the processed and validated form data.', null=True, on_delete=django.db.models.deletion.PROTECT, to='slackforms.Endpoint'),
        ),
    ]
