# Generated by Django 2.1.4 on 2018-12-04 17:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0005_auto_20181204_1731'),
    ]

    operations = [
        migrations.AlterField(
            model_name='form',
            name='webhook',
            field=models.URLField(blank=True, help_text='A URL to hit with the processed and validated form data.'),
        ),
    ]
