# Generated by Django 2.1.4 on 2018-12-03 18:59

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Form',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.TextField(unique=True)),
                ('webhook', models.URLField(blank=True)),
                ('json_schema', django.contrib.postgres.fields.jsonb.JSONField(null=True)),
                ('ui_schema', django.contrib.postgres.fields.jsonb.JSONField(null=True)),
            ],
        ),
    ]
