# Generated by Django 2.1.4 on 2018-12-04 17:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0004_auto_20181204_1729'),
    ]

    operations = [
        migrations.AlterField(
            model_name='form',
            name='argument_prop_name',
            field=models.CharField(blank=True, help_text='The prop name of the argument of the slash command.', max_length=40, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='form',
            name='slash_command',
            field=models.CharField(blank=True, help_text="The slash command for this form (don't include the slash).", max_length=40, null=True, unique=True),
        ),
    ]
