# Generated by Django 2.1.4 on 2018-12-13 19:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0009_auto_20181213_1921'),
    ]

    operations = [
        migrations.AlterField(
            model_name='endpoint',
            name='url',
            field=models.URLField(help_text='A URL to hit with the processed and validated form data.'),
        ),
    ]
