# Generated by Django 2.1.4 on 2018-12-06 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0007_auto_20181205_1625'),
    ]

    operations = [
        migrations.AlterField(
            model_name='form',
            name='data_source',
            field=models.URLField(blank=True, default='http://example.com', help_text='\nThe source of data if an Id is supplied. Variable is passed through to\nthis template. Use "{id}" to crate the template.\n'),
            preserve_default=False,
        ),
    ]
