# Generated by Django 2.1.4 on 2018-12-13 19:54

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0011_auto_20181213_1953'),
    ]

    operations = [
        migrations.AlterField(
            model_name='form',
            name='json_schema',
            field=django.contrib.postgres.fields.jsonb.JSONField(help_text='A schema for the form data. See docs.'),
        ),
        migrations.AlterField(
            model_name='form',
            name='ui_schema',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, help_text='A schema for the form inputs. See docs.', null=True),
        ),
    ]
