# Generated by Django 2.1.4 on 2018-12-04 17:28

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0002_auto_20181203_1901'),
    ]

    operations = [
        migrations.AddField(
            model_name='form',
            name='argument_name',
            field=models.CharField(blank=True, help_text='The prop name to map the argument passed from the slash command', max_length=40, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='form',
            name='slash_command',
            field=models.CharField(blank=True, help_text='A slash command mapped to this form', max_length=40, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='form',
            name='json_schema',
            field=django.contrib.postgres.fields.jsonb.JSONField(help_text='A schema for the form data. See docs.', null=True),
        ),
        migrations.AlterField(
            model_name='form',
            name='name',
            field=models.CharField(help_text='The unique name of this form to serve as a unique key.', max_length=20, unique=True),
        ),
        migrations.AlterField(
            model_name='form',
            name='ui_schema',
            field=django.contrib.postgres.fields.jsonb.JSONField(help_text='A schema for the form inputs. See docs.', null=True),
        ),
        migrations.AlterField(
            model_name='form',
            name='webhook',
            field=models.URLField(blank=True, help_text='A URL to hit with the processed and validated form data'),
        ),
    ]
