# Generated by Django 2.1.4 on 2018-12-03 19:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slackforms', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='form',
            name='name',
            field=models.CharField(max_length=20, unique=True),
        ),
    ]
